@@ -1,12 +1,15 @@
+from __future__ import absolute_import
+
 from time import time
 from threading import Thread
-from Queue import Queue, Empty
 from subprocess import Popen, PIPE, STDOUT
 
-from ringbuffer import RingBuffer
-from exceptions import Timeout, EOF, UnexpectedExit
+from .six import PY3
+from .six.moves import queue
+from .ringbuffer import RingBuffer
+from .exceptions import Timeout, EOF, UnexpectedExit
 
-__version__ = '0.4.4'
+__version__ = '0.5.0'
 
 
 class What(Popen):
@@ -31,7 +34,7 @@ class What(Popen):
         kwargs['close_fds'] = True
         super(What, self).__init__(args, **kwargs)
         self.timeout = 10
-        self.queue = Queue(self.BUFFER_SIZE)
+        self.queue = queue.Queue(self.BUFFER_SIZE)
         self.lines = RingBuffer(self.BUFFER_SIZE)
         self.reader = Thread(target=self._enqueue_output)
         self.reader.daemon = True
@@ -64,7 +67,7 @@ class What(Popen):
 
                 if string in line:
                     return line
-        except Empty:
+        except queue.Empty:
             raise Timeout(self, string)
 
     def expect_exit(self, exit_code=None, timeout=None):
@@ -98,6 +101,8 @@ class What(Popen):
     def _enqueue_output(self):
         """Thread target of self.reader."""
         for line in iter(self.stdout.readline, b''):
+            if PY3:
+                line = line.decode('utf-8')
             line = line.rstrip('\n')
             self.queue.put(line)
             self.lines.append(line)
